@@ -19,8 +19,9 @@
 /* This file contains functions for controlling local X servers */
 
 #include <config.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 #include <stdio.h>
+#include <unistd.h>
 #include <stdlib.h>
 #include <fcntl.h>
 #include <pwd.h>
@@ -66,6 +67,8 @@ extern int extra_status;
 
 /* Global vars */
 static GdmDisplay *d = NULL;
+static gboolean server_signal_notified = FALSE;
+static int server_signal_pipe[2];
 
 /* Wipe cookie files */
 void
@@ -329,10 +332,17 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
     gdm_debug ("gdm_server_start: %s", d->name);
 
     /* Create new cookie */
-    if ( ! gdm_auth_secure_display (d))
+    if ( ! gdm_auth_secure_display (d)) 
 	    return FALSE;
     gdm_slave_send_string (GDM_SOP_COOKIE, d->cookie);
-    ve_setenv ("DISPLAY", d->name, TRUE);
+    gnome_setenv ("DISPLAY", d->name, TRUE);
+
+    if (pipe (server_signal_pipe) != 0) {
+	    gdm_error (_("%s: Error openning a pipe: %s"),
+		       "gdm_server_start", g_strerror (errno));
+	    return FALSE; 
+    }
+    server_signal_notified = FALSE;
 
     /* Catch USR1 from X server */
     usr1.sa_handler = gdm_server_usr1_handler;
@@ -340,7 +350,10 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
     sigemptyset (&usr1.sa_mask);
 
     if (sigaction (SIGUSR1, &usr1, &old_usr1) < 0) {
-	    gdm_error (_("gdm_server_start: Error setting up USR1 signal handler"));
+	    gdm_error (_("%s: Error setting up USR1 signal handler: %s"),
+		       "gdm_server_start", g_strerror (errno));
+	    close (server_signal_pipe[0]);
+	    close (server_signal_pipe[1]);
 	    return FALSE;
     }
 
@@ -350,8 +363,11 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
     sigemptyset (&chld.sa_mask);
 
     if (sigaction (SIGCHLD, &chld, &old_chld) < 0) {
-	    gdm_error (_("gdm_server_start: Error setting up CHLD signal handler"));
+	    gdm_error (_("%s: Error setting up CHLD signal handler: %s"),
+		       "gdm_server_start", g_strerror (errno));
 	    sigaction (SIGUSR1, &old_usr1, NULL);
+	    close (server_signal_pipe[0]);
+	    close (server_signal_pipe[1]);
 	    return FALSE;
     }
 
@@ -361,9 +377,12 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
     sigemptyset (&alrm.sa_mask);
 
     if (sigaction (SIGALRM, &alrm, &old_alrm) < 0) {
-	    gdm_error (_("gdm_server_start: Error setting up ALRM signal handler"));
+	    gdm_error (_("%s: Error setting up ALRM signal handler: %s"),
+		       "gdm_server_start", g_strerror (errno));
 	    sigaction (SIGUSR1, &old_usr1, NULL);
 	    sigaction (SIGCHLD, &old_chld, NULL);
+	    close (server_signal_pipe[0]);
+	    close (server_signal_pipe[1]);
 	    return FALSE;
     }
 
@@ -398,7 +417,7 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
 		     * use USR1 of course, so try openning the display 
 		     * as a test, but the */
 
-		    ve_setenv ("XAUTHORITY", d->authfile, TRUE);
+		    gnome_setenv ("XAUTHORITY", d->authfile, TRUE);
 		    for (i = 0;
 			 d->dsp == NULL &&
 			 d->servstat == SERVER_STARTED &&
@@ -410,14 +429,25 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
 			    else
 				    d->servstat = SERVER_RUNNING;
 		    }
-		    ve_unsetenv ("XAUTHORITY");
+		    gnome_unsetenv ("XAUTHORITY");
 		    if (d->dsp == NULL &&
 			/* Note: we could have still gotten a SIGCHLD */
 			d->servstat == SERVER_STARTED) {
 			    d->servstat = SERVER_TIMEOUT;
 		    }
 	    } else {
-		    gdm_run ();
+		    fd_set rfds;
+
+		    gdm_debug ("gdm_server_start: Before mainloop waiting for server");
+
+		    FD_ZERO (&rfds);
+		    FD_SET (server_signal_pipe[0], &rfds);
+
+		    do {
+			    select (server_signal_pipe[0]+1, &rfds, NULL, NULL, NULL);
+		    } while ( ! server_signal_notified);
+
+		    gdm_debug ("gdm_server_start: After mainloop waiting for server");
 	    }
     }
 
@@ -446,6 +476,9 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
 	    sigaction (SIGCHLD, &old_chld, NULL);
 	    sigaction (SIGALRM, &old_alrm, NULL);
 
+	    close (server_signal_pipe[0]);
+	    close (server_signal_pipe[1]);
+
 	    if (SERVER_IS_FLEXI (d))
 		    gdm_slave_send_num (GDM_SOP_FLEXI_OK, 0 /* bogus */);
 #ifdef __linux__
@@ -483,6 +516,9 @@ gdm_server_start (GdmDisplay *disp, gboolean treat_as_flexi,
     sigaction (SIGCHLD, &old_chld, NULL);
     sigaction (SIGALRM, &old_alrm, NULL);
 
+    close (server_signal_pipe[0]);
+    close (server_signal_pipe[1]);
+
     if (disp->type == TYPE_FLEXI_XNEST &&
 	display_xnest_no_connect (disp)) {
 	    gdm_slave_send_num (GDM_SOP_FLEXI_ERR,
@@ -697,11 +733,11 @@ gdm_server_spawn (GdmDisplay *d)
 	sigprocmask (SIG_UNBLOCK, &mask, NULL);
 
 	if (d->type == TYPE_FLEXI_XNEST) {
-		ve_setenv ("DISPLAY", d->xnest_disp, TRUE);
+		gnome_setenv ("DISPLAY", d->xnest_disp, TRUE);
 		if (d->xnest_auth_file != NULL)
-			ve_setenv ("XAUTHORITY", d->xnest_auth_file, TRUE);
+			gnome_setenv ("XAUTHORITY", d->xnest_auth_file, TRUE);
 		else
-			ve_unsetenv ("XAUTHORITY");
+			gnome_unsetenv ("XAUTHORITY");
 	}
 
 	bin = ve_first_word (d->command);
@@ -777,12 +813,12 @@ gdm_server_spawn (GdmDisplay *d)
 			_exit (SERVER_ABORT);
 		}
 		if (pwent->pw_dir != NULL &&
-		    g_file_exists (pwent->pw_dir))
-			ve_setenv ("HOME", pwent->pw_dir, TRUE);
+		    g_file_test (pwent->pw_dir, G_FILE_TEST_EXISTS))
+			gnome_setenv ("HOME", pwent->pw_dir, TRUE);
 		else
-			ve_setenv ("HOME", "/", TRUE); /* Hack */
-		ve_setenv ("SHELL", pwent->pw_shell, TRUE);
-		ve_unsetenv ("MAIL");
+			gnome_setenv ("HOME", "/", TRUE); /* Hack */
+		gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
+		gnome_unsetenv ("MAIL");
 
 		if (setgid (pwent->pw_gid) < 0)  {
 			gdm_error (_("%s: Couldn't set groupid to %d"), 
@@ -832,7 +868,6 @@ gdm_server_spawn (GdmDisplay *d)
     }
 }
 
-
 /**
  * gdm_server_usr1_handler:
  * @sig: Signal value
@@ -848,7 +883,9 @@ gdm_server_usr1_handler (gint sig)
 
     gdm_debug ("gdm_server_usr1_handler: Got SIGUSR1, server running");
 
-    gdm_quit ();
+    server_signal_notified = TRUE;
+    /* this will quit the select */
+    write (server_signal_pipe[1], "Yay!", 4);
 }
 
 
@@ -866,7 +903,9 @@ gdm_server_alarm_handler (gint signal)
 
     gdm_debug ("gdm_server_alarm_handler: Got SIGALRM, server abort");
 
-    gdm_quit ();
+    server_signal_notified = TRUE;
+    /* this will quit the select */
+    write (server_signal_pipe[1], "Yay!", 4);
 }
 
 
@@ -902,7 +941,9 @@ gdm_server_child_handler (int signal)
 			d->servstat = SERVER_ABORT;	/* Server died unexpectedly */
 			d->servpid = 0;
 
-			gdm_quit ();
+			server_signal_notified = TRUE;
+			/* this will quit the select */
+			write (server_signal_pipe[1], "Yay!", 4);
 		} else if (pid == extra_process) {
 			/* an extra process died, yay! */
 			extra_process = -1;
