@@ -20,10 +20,12 @@
  * and the user's session scripts. */
 
 #include <config.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <gtk/gtkmessagedialog.h>
 #include <gdk/gdkx.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -57,7 +59,6 @@
 #include "choose.h"
 #include "errorgui.h"
 
-
 /* Some per slave globals */
 static GdmDisplay *d;
 static gchar *login = NULL;
@@ -168,7 +169,9 @@ gdm_slave_start (GdmDisplay *display)
 		sigaddset (&alrm.sa_mask, SIGALRM);
 
 		if (sigaction (SIGALRM, &alrm, NULL) < 0)
-			gdm_slave_exit (DISPLAY_ABORT, _("gdm_slave_init: Error setting up ALRM signal handler"));
+			gdm_slave_exit (DISPLAY_ABORT,
+					_("%s: Error setting up ALRM signal handler: %s"),
+					"gdm_slave_start", g_strerror (errno));
 	}
 
 	/* Handle a INT/TERM signals from gdm master */
@@ -180,7 +183,9 @@ gdm_slave_start (GdmDisplay *display)
 
 	if ((sigaction (SIGTERM, &term, NULL) < 0) ||
 	    (sigaction (SIGINT, &term, NULL) < 0))
-		gdm_slave_exit (DISPLAY_ABORT, _("gdm_slave_init: Error setting up TERM/INT signal handler"));
+		gdm_slave_exit (DISPLAY_ABORT,
+				_("%s: Error setting up TERM/INT signal handler: %s"),
+				"gdm_slave_start", g_strerror (errno));
 
 	/* Child handler. Keeps an eye on greeter/session */
 	child.sa_handler = gdm_slave_child_handler;
@@ -189,7 +194,8 @@ gdm_slave_start (GdmDisplay *display)
 	sigaddset (&child.sa_mask, SIGCHLD);
 
 	if (sigaction (SIGCHLD, &child, NULL) < 0) 
-		gdm_slave_exit (DISPLAY_ABORT, _("gdm_slave_init: Error setting up CHLD signal handler"));
+		gdm_slave_exit (DISPLAY_ABORT, _("%s: Error setting up CHLD signal handler: %s"),
+				"gdm_slave_start", g_strerror (errno));
 
 	/* Handle a USR2 which is ack from master that it received a message */
 	usr2.sa_handler = gdm_slave_usr2_handler;
@@ -198,7 +204,8 @@ gdm_slave_start (GdmDisplay *display)
 	sigaddset (&usr2.sa_mask, SIGUSR2);
 
 	if (sigaction (SIGUSR2, &usr2, NULL) < 0)
-		gdm_slave_exit (DISPLAY_ABORT, _("%s: Error setting up USR2 signal handler"), "gdm_slave_init");
+		gdm_slave_exit (DISPLAY_ABORT, _("%s: Error setting up USR2 signal handler: %s"),
+				"gdm_slave_start", g_strerror (errno));
 
 	/* The signals we wish to listen to */
 	sigfillset (&mask);
@@ -373,8 +380,8 @@ gdm_slave_run (GdmDisplay *display)
 	    gdm_slave_send_num (GDM_SOP_XPID, d->servpid);
     }
     
-    ve_setenv ("XAUTHORITY", d->authfile, TRUE);
-    ve_setenv ("DISPLAY", d->name, TRUE);
+    gnome_setenv ("XAUTHORITY", d->authfile, TRUE);
+    gnome_setenv ("DISPLAY", d->name, TRUE);
 
     /* Now the display name and hostname is final */
     if ( ! ve_string_empty (GdmAutomaticLogin)) {
@@ -643,15 +650,15 @@ run_config (GdmDisplay *display, struct passwd *pwent)
 		gdm_clearenv_no_lang ();
 
 		/* root here */
-		ve_setenv ("XAUTHORITY", display->authfile, TRUE);
-		ve_setenv ("DISPLAY", display->name, TRUE);
-		ve_setenv ("LOGNAME", "root", TRUE);
-		ve_setenv ("USER", "root", TRUE);
-		ve_setenv ("USERNAME", "root", TRUE);
-		ve_setenv ("HOME", pwent->pw_dir, TRUE);
-		ve_setenv ("SHELL", pwent->pw_shell, TRUE);
-		ve_setenv ("PATH", GdmRootPath, TRUE);
-		ve_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
+		gnome_setenv ("XAUTHORITY", display->authfile, TRUE);
+		gnome_setenv ("DISPLAY", display->name, TRUE);
+		gnome_setenv ("LOGNAME", "root", TRUE);
+		gnome_setenv ("USER", "root", TRUE);
+		gnome_setenv ("USERNAME", "root", TRUE);
+		gnome_setenv ("HOME", pwent->pw_dir, TRUE);
+		gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
+		gnome_setenv ("PATH", GdmRootPath, TRUE);
+		gnome_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
 
 		for (i = 0; i < sysconf (_SC_OPEN_MAX); i++)
 			close(i);
@@ -670,7 +677,7 @@ run_config (GdmDisplay *display, struct passwd *pwent)
 			execv (argv[0], argv);
 
 		gdm_error_box (d,
-			       GNOME_MESSAGE_BOX_ERROR,
+			       GTK_MESSAGE_ERROR,
 			       _("Could not execute the configuration\n"
 				 "program.  Make sure it's path is set\n"
 				 "correctly in the configuration file.\n"
@@ -684,7 +691,7 @@ run_config (GdmDisplay *display, struct passwd *pwent)
 			execv (argv[0], argv);
 
 		gdm_error_box (d,
-			       GNOME_MESSAGE_BOX_ERROR,
+			       GTK_MESSAGE_ERROR,
 			       _("Could not execute the configuration\n"
 				 "program.  Make sure it's path is set\n"
 				 "correctly in the configuration file."));
@@ -845,19 +852,27 @@ gdm_slave_wait_for_login (void)
 static gboolean
 is_in_trusted_pic_dir (const char *path)
 {
-	char *globalpix;
+	GSList *locations = NULL, *li;
 
 	/* our own pixmap dir is trusted */
 	if (strncmp (path, EXPANDED_PIXMAPDIR, sizeof (EXPANDED_PIXMAPDIR)) == 0)
 		return TRUE;
 
-	/* gnome'skpixmap dir is trusted */
-	globalpix = gnome_unconditional_pixmap_file ("");
-	if (strncmp (path, globalpix, strlen (globalpix)) == 0) {
-		g_free (globalpix);
-		return TRUE;
+	g_free (gnome_program_locate_file (NULL /* program */,
+					   GNOME_FILE_DOMAIN_PIXMAP,
+					   "" /* file_name */,
+					   FALSE /* only_if_exists */,
+					   &locations));
+	for (li = locations; li != NULL; li = li->next) {
+		/* gnome's pixmap dirs are trusted */
+		if (strncmp (path, li->data, strlen (li->data)) == 0) {
+			g_slist_foreach (locations, (GFunc)g_free, NULL);
+			g_slist_free (locations);
+			return TRUE;
+		}
 	}
-	g_free (globalpix);
+	g_slist_foreach (locations, (GFunc)g_free, NULL);
+	g_slist_free (locations);
 
 	return FALSE;
 }
@@ -925,6 +940,7 @@ run_pictures (void)
 
 			if (picfile != NULL) {
 				char *dir;
+				char *base;
 
 				/* if in trusted dir, just use it */
 				if (is_in_trusted_pic_dir (picfile)) {
@@ -940,19 +956,21 @@ run_pictures (void)
 				}
 
 				/* if not in trusted dir, check it out */
-				dir = g_dirname (picfile);
+				dir = g_path_get_dirname (picfile);
+				base = g_path_get_basename (picfile);
 
 				/* Note that strict permissions checking is done
 				 * on this file.  Even if it may not even be owned by the
 				 * user.  This setting should ONLY point to pics in trusted
 				 * dirs. */
 				if ( ! gdm_file_check ("run_pictures", pwent->pw_uid,
-						       dir, g_basename (picfile), TRUE, GdmUserMaxFile,
+						       dir, base, TRUE, GdmUserMaxFile,
 						       GdmRelaxPerms)) {
 					g_free (picfile);
 					picfile = NULL;
 				}
 
+				g_free (base);
 				g_free (dir);
 			}
 		}
@@ -1021,7 +1039,7 @@ run_pictures (void)
 		}
 
 		strcpy (tempname, "/tmp/gdm-user-picture-XXXXXX");
-		tempfd = mkstemp (tempname);
+		tempfd = g_mkstemp (tempname);
 
 		if (tempfd < 0) {
 			fclose (fp);
@@ -1119,63 +1137,63 @@ gdm_slave_greeter (void)
 			    "gdm_slave_greeter", GdmUserId);
 	
 	gdm_clearenv_no_lang ();
-	ve_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
-	ve_setenv ("DISPLAY", d->name, TRUE);
+	gnome_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
+	gnome_setenv ("DISPLAY", d->name, TRUE);
 
-	ve_setenv ("LOGNAME", GdmUser, TRUE);
-	ve_setenv ("USER", GdmUser, TRUE);
-	ve_setenv ("USERNAME", GdmUser, TRUE);
-	ve_setenv ("GDM_GREETER_PROTOCOL_VERSION",
-		   GDM_GREETER_PROTOCOL_VERSION, TRUE);
-	ve_setenv ("GDM_VERSION", VERSION, TRUE);
+	gnome_setenv ("LOGNAME", GdmUser, TRUE);
+	gnome_setenv ("USER", GdmUser, TRUE);
+	gnome_setenv ("USERNAME", GdmUser, TRUE);
+	gnome_setenv ("GDM_GREETER_PROTOCOL_VERSION",
+		      GDM_GREETER_PROTOCOL_VERSION, TRUE);
+	gnome_setenv ("GDM_VERSION", VERSION, TRUE);
 
 	pwent = getpwnam (GdmUser);
 	if (pwent != NULL) {
 		/* Note that usually this doesn't exist */
 		if (pwent->pw_dir != NULL &&
-		    g_file_exists (pwent->pw_dir))
-			ve_setenv ("HOME", pwent->pw_dir, TRUE);
+		    g_file_test (pwent->pw_dir, G_FILE_TEST_EXISTS))
+			gnome_setenv ("HOME", pwent->pw_dir, TRUE);
 		else
-			ve_setenv ("HOME", "/", TRUE); /* Hack */
-		ve_setenv ("SHELL", pwent->pw_shell, TRUE);
+			gnome_setenv ("HOME", "/", TRUE); /* Hack */
+		gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
 	} else {
-		ve_setenv ("HOME", "/", TRUE); /* Hack */
-		ve_setenv ("SHELL", "/bin/sh", TRUE);
+		gnome_setenv ("HOME", "/", TRUE); /* Hack */
+		gnome_setenv ("SHELL", "/bin/sh", TRUE);
 	}
-	ve_setenv ("PATH", GdmDefaultPath, TRUE);
-	ve_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
+	gnome_setenv ("PATH", GdmDefaultPath, TRUE);
+	gnome_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
 
 	/* Note that this is just informative, the slave will not listen to
 	 * the greeter even if it does something it shouldn't on a non-local
 	 * display so it's not a security risk */
 	if (d->console) {
-		ve_setenv ("GDM_IS_LOCAL", "yes", TRUE);
+		gnome_setenv ("GDM_IS_LOCAL", "yes", TRUE);
 	} else {
-		ve_unsetenv ("GDM_IS_LOCAL");
+		gnome_unsetenv ("GDM_IS_LOCAL");
 	}
 
 	/* this is again informal only, if the greeter does time out it will
 	 * not actually login a user if it's not enabled for this display */
 	if (d->timed_login_ok) {
 		if(ParsedTimedLogin == NULL)
-			ve_setenv ("GDM_TIMED_LOGIN_OK", " ", TRUE);
+			gnome_setenv ("GDM_TIMED_LOGIN_OK", " ", TRUE);
 		else
-			ve_setenv ("GDM_TIMED_LOGIN_OK", ParsedTimedLogin, TRUE);
+			gnome_setenv ("GDM_TIMED_LOGIN_OK", ParsedTimedLogin, TRUE);
 	} else {
-		ve_unsetenv ("GDM_TIMED_LOGIN_OK");
+		gnome_unsetenv ("GDM_TIMED_LOGIN_OK");
 	}
 
 	if (d->type == TYPE_FLEXI) {
-		ve_setenv ("GDM_FLEXI_SERVER", "yes", TRUE);
+		gnome_setenv ("GDM_FLEXI_SERVER", "yes", TRUE);
 	} else if (d->type == TYPE_FLEXI_XNEST) {
-		ve_setenv ("GDM_FLEXI_SERVER", "Xnest", TRUE);
+		gnome_setenv ("GDM_FLEXI_SERVER", "Xnest", TRUE);
 	} else {
-		ve_unsetenv ("GDM_FLEXI_SERVER");
+		gnome_unsetenv ("GDM_FLEXI_SERVER");
 	}
 
 	if(gdm_emergency_server) {
 		gdm_error_box (d,
-			       GNOME_MESSAGE_BOX_ERROR,
+			       GTK_MESSAGE_ERROR,
 			       _("No servers were defined in the\n"
 				 "configuration file and xdmcp was\n"
 				 "disabled.  This can only be a\n"
@@ -1184,12 +1202,12 @@ gdm_slave_greeter (void)
 				 "log in and fix the configuration.\n"
 				 "Note that automatic and timed logins\n"
 				 "are disabled now."));
-		ve_unsetenv ("GDM_TIMED_LOGIN_OK");
+		gnome_unsetenv ("GDM_TIMED_LOGIN_OK");
 	}
 
 	if (d->failsafe_xserver) {
 		gdm_error_box (d,
-			       GNOME_MESSAGE_BOX_ERROR,
+			       GTK_MESSAGE_ERROR,
 			       _("I could not start the regular X\n"
 				 "server (your graphical environment)\n"
 				 "and so this is a failsafe X server.\n"
@@ -1202,7 +1220,7 @@ gdm_slave_greeter (void)
 			(_("The specified display number was busy, so "
 			   "this server was started on display %s."),
 			 d->name);
-		gdm_error_box (d, GNOME_MESSAGE_BOX_ERROR, msg);
+		gdm_error_box (d, GTK_MESSAGE_ERROR, msg);
 		g_free (msg);
 	}
 
@@ -1213,14 +1231,14 @@ gdm_slave_greeter (void)
 		   EXPANDED_BINDIR
 		   "/gdmlogin --disable-sound --disable-crash-dialog");
 
-	ve_setenv ("GDM_WHACKED_GREETER_CONFIG", "true", TRUE);
+	gnome_setenv ("GDM_WHACKED_GREETER_CONFIG", "true", TRUE);
 
 	argv = ve_split (EXPANDED_BINDIR
 			 "/gdmlogin --disable-sound --disable-crash-dialog");
 	execv (argv[0], argv);
 
 	gdm_error_box (d,
-		       GNOME_MESSAGE_BOX_ERROR,
+		       GTK_MESSAGE_ERROR,
 		       _("Cannot start the greeter program,\n"
 			 "you will not be able to log in.\n"
 			 "This display will be disabled.\n"
@@ -1464,35 +1482,35 @@ gdm_slave_chooser (void)
 					"gdm_slave_chooser", GdmUserId);
 
 		gdm_clearenv_no_lang ();
-		ve_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
-		ve_setenv ("DISPLAY", d->name, TRUE);
+		gnome_setenv ("XAUTHORITY", GDM_AUTHFILE (d), TRUE);
+		gnome_setenv ("DISPLAY", d->name, TRUE);
 
-		ve_setenv ("LOGNAME", GdmUser, TRUE);
-		ve_setenv ("USER", GdmUser, TRUE);
-		ve_setenv ("USERNAME", GdmUser, TRUE);
+		gnome_setenv ("LOGNAME", GdmUser, TRUE);
+		gnome_setenv ("USER", GdmUser, TRUE);
+		gnome_setenv ("USERNAME", GdmUser, TRUE);
 
-		ve_setenv ("GDM_VERSION", VERSION, TRUE);
+		gnome_setenv ("GDM_VERSION", VERSION, TRUE);
 
 		pwent = getpwnam (GdmUser);
 		if (pwent != NULL) {
 			/* Note that usually this doesn't exist */
-			if (g_file_exists (pwent->pw_dir))
-				ve_setenv ("HOME", pwent->pw_dir, TRUE);
+			if (g_file_test (pwent->pw_dir, G_FILE_TEST_EXISTS))
+				gnome_setenv ("HOME", pwent->pw_dir, TRUE);
 			else
-				ve_setenv ("HOME", "/", TRUE); /* Hack */
-			ve_setenv ("SHELL", pwent->pw_shell, TRUE);
+				gnome_setenv ("HOME", "/", TRUE); /* Hack */
+			gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
 		} else {
-			ve_setenv ("HOME", "/", TRUE); /* Hack */
-			ve_setenv ("SHELL", "/bin/sh", TRUE);
+			gnome_setenv ("HOME", "/", TRUE); /* Hack */
+			gnome_setenv ("SHELL", "/bin/sh", TRUE);
 		}
-		ve_setenv ("PATH", GdmDefaultPath, TRUE);
-		ve_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
+		gnome_setenv ("PATH", GdmDefaultPath, TRUE);
+		gnome_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
 
 		argv = ve_split (GdmChooser);
 		execv (argv[0], argv);
 
 		gdm_error_box (d,
-			       GNOME_MESSAGE_BOX_ERROR,
+			       GTK_MESSAGE_ERROR,
 			       _("Cannot start the chooser program,\n"
 				 "you will not be able to log in.\n"
 				 "Please contact the system administrator.\n"));
@@ -1720,7 +1738,7 @@ find_prog (const char *name, const char *args, char **retpath)
 		NULL
 	};
 
-	path = gnome_is_program_in_path (name);
+	path = g_find_program_in_path (name);
 	if (path != NULL &&
 	    access (path, X_OK) == 0) {
 		ret = g_strdup_printf ("%s %s", path, args);
@@ -1773,7 +1791,7 @@ unaliaslang (const char *origlang)
 		if (lang == NULL)
 			continue;
 
-		if (ve_strcasecmp_no_locale (name, origlang) == 0) {
+		if (g_ascii_strcasecmp (name, origlang) == 0) {
 			fclose (langlist);
 			return g_strdup (lang);
 		}
@@ -1824,27 +1842,27 @@ session_child_run (struct passwd *pwent,
 	gboolean need_config_sync = FALSE;
 	const char *shell = NULL;
 
-	ve_clearenv ();
+	gdm_clearenv ();
 
 	/* Prepare user session */
-	ve_setenv ("XAUTHORITY", d->userauth, TRUE);
-	ve_setenv ("DISPLAY", d->name, TRUE);
-	ve_setenv ("LOGNAME", login, TRUE);
-	ve_setenv ("USER", login, TRUE);
-	ve_setenv ("USERNAME", login, TRUE);
-	ve_setenv ("HOME", home_dir, TRUE);
-	ve_setenv ("GDMSESSION", session, TRUE);
-	ve_setenv ("SHELL", pwent->pw_shell, TRUE);
-	ve_unsetenv ("MAIL");	/* Unset $MAIL for broken shells */
+	gnome_setenv ("XAUTHORITY", d->userauth, TRUE);
+	gnome_setenv ("DISPLAY", d->name, TRUE);
+	gnome_setenv ("LOGNAME", login, TRUE);
+	gnome_setenv ("USER", login, TRUE);
+	gnome_setenv ("USERNAME", login, TRUE);
+	gnome_setenv ("HOME", home_dir, TRUE);
+	gnome_setenv ("GDMSESSION", session, TRUE);
+	gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
+	gnome_unsetenv ("MAIL");	/* Unset $MAIL for broken shells */
 
 	if (gnome_session != NULL)
-		ve_setenv ("GDM_GNOME_SESSION", gnome_session, TRUE);
+		gnome_setenv ("GDM_GNOME_SESSION", gnome_session, TRUE);
 
 	/* Special PATH for root */
 	if (pwent->pw_uid == 0)
-		ve_setenv ("PATH", GdmRootPath, TRUE);
+		gnome_setenv ("PATH", GdmRootPath, TRUE);
 	else
-		ve_setenv ("PATH", GdmDefaultPath, TRUE);
+		gnome_setenv ("PATH", GdmDefaultPath, TRUE);
 
 	/* Eeeeek, this no lookie as a correct language code, let's
 	 * try unaliasing it */
@@ -1854,8 +1872,8 @@ session_child_run (struct passwd *pwent,
 	}
 
 	/* Set locale */
-	ve_setenv ("LANG", language, TRUE);
-	ve_setenv ("GDM_LANG", language, TRUE);
+	gnome_setenv ("LANG", language, TRUE);
+	gnome_setenv ("GDM_LANG", language, TRUE);
     
 	setpgid (0, 0);
 	
@@ -1868,10 +1886,6 @@ session_child_run (struct passwd *pwent,
 				  "Aborting."),
 				"gdm_slave_session_start", login);
 
-	/* setup egid to the correct group,
-	 * not to leave the egid around */
-	setegid (pwent->pw_gid);
-
 	if (setuid (pwent->pw_uid) < 0) 
 		gdm_child_exit (DISPLAY_REMANAGE,
 				_("gdm_slave_session_start: Could not become %s. Aborting."), login);
@@ -1943,13 +1957,13 @@ session_child_run (struct passwd *pwent,
 			gdm_error (_("gdm_slave_session_start: gnome-session not found for a failsafe gnome session, trying xterm"));
 			session = GDM_SESSION_FAILSAFE_XTERM;
 			gdm_error_box
-				(d, GNOME_MESSAGE_BOX_ERROR,
+				(d, GTK_MESSAGE_ERROR,
 				 _("Could not find the GNOME installation,\n"
 				   "will try running the \"Failsafe xterm\"\n"
 				   "session."));
 		} else {
 			gdm_error_box
-				(d, GNOME_MESSAGE_BOX_INFO,
+				(d, GTK_MESSAGE_INFO,
 				 _("This is the Failsafe Gnome session.\n"
 				   "You will be logged into the 'Default'\n"
 				   "session of Gnome with no startup scripts\n"
@@ -1968,14 +1982,14 @@ session_child_run (struct passwd *pwent,
 				      &sessexec);
 		g_free (params);
 		if (sesspath == NULL) {
-			gdm_error_box (d, GNOME_MESSAGE_BOX_ERROR,
+			gdm_error_box (d, GTK_MESSAGE_ERROR,
 				       _("Cannot find \"xterm\" to start "
 					 "a failsafe session."));
 			/* nyah nyah nyah nyah nyah */
 			_exit (0);
 		} else {
 			gdm_error_box
-				(d, GNOME_MESSAGE_BOX_INFO,
+				(d, GTK_MESSAGE_INFO,
 				 _("This is the Failsafe xterm session.\n"
 				   "You will be logged into a terminal\n"
 				   "console so that you may fix your system\n"
@@ -2013,7 +2027,7 @@ session_child_run (struct passwd *pwent,
 	    strcmp (shell, "/bin/false") == 0 ||
 	    strcmp (shell, "/bin/true") == 0) {
 		gdm_error (_("gdm_slave_session_start: User not allowed to log in"));
-		gdm_error_box (d, GNOME_MESSAGE_BOX_ERROR,
+		gdm_error_box (d, GTK_MESSAGE_ERROR,
 			       _("The system administrator has\n"
 				 "disabled your account."));
 	} else if (access (sessexec != NULL ? sessexec : sesspath, X_OK) != 0) {
@@ -2021,7 +2035,7 @@ session_child_run (struct passwd *pwent,
 		/* if we can't read and exec the session, then make a nice
 		 * error dialog */
 		gdm_error_box
-			(d, GNOME_MESSAGE_BOX_ERROR,
+			(d, GTK_MESSAGE_ERROR,
 			 _("Cannot start the session, most likely the\n"
 			   "session does not exist.  Please select from\n"
 			   "the list of available sessions in the login\n"
@@ -2032,7 +2046,7 @@ session_child_run (struct passwd *pwent,
 
 		gdm_error (_("gdm_slave_session_start: Could not start session `%s'"), sesspath);
 		gdm_error_box
-			(d, GNOME_MESSAGE_BOX_ERROR,
+			(d, GTK_MESSAGE_ERROR,
 			 _("Cannot start your shell.  It could be that the\n"
 			   "system administrator has disabled your login.\n"
 			   "It could also indicate an error with your account.\n"));
@@ -2069,7 +2083,7 @@ gdm_slave_session_start (void)
     }
 
     if (pwent->pw_dir == NULL ||
-	! g_file_test (pwent->pw_dir, G_FILE_TEST_ISDIR)) {
+	! g_file_test (pwent->pw_dir, G_FILE_TEST_IS_DIR)) {
 	    char *msg = g_strdup_printf (
 		     _("Your home directory is listed as:\n'%s'\n"
 		       "but it does not appear to exist.\n"
@@ -2238,7 +2252,7 @@ gdm_slave_session_start (void)
 	    gdm_server_whack_clients (d);
 
     /* setup some env for PreSession script */
-    ve_setenv ("DISPLAY", d->name, TRUE);
+    gnome_setenv ("DISPLAY", d->name, TRUE);
 
     /* If script fails reset X server and restart greeter */
     if (gdm_slave_exec_script (d, GdmPreSession,
@@ -2750,31 +2764,31 @@ gdm_slave_exec_script (GdmDisplay *d, const gchar *dir, const char *login,
         open ("/dev/null", O_RDWR); /* open stderr - fd 2 */
 
         if (login != NULL) {
-	        ve_setenv ("LOGNAME", login, TRUE);
-	        ve_setenv ("USER", login, TRUE);
-	        ve_setenv ("USERNAME", login, TRUE);
+	        gnome_setenv ("LOGNAME", login, TRUE);
+	        gnome_setenv ("USER", login, TRUE);
+	        gnome_setenv ("USERNAME", login, TRUE);
         } else {
-	        ve_setenv ("LOGNAME", GdmUser, TRUE);
-	        ve_setenv ("USER", GdmUser, TRUE);
-	        ve_setenv ("USERNAME", GdmUser, TRUE);
+	        gnome_setenv ("LOGNAME", GdmUser, TRUE);
+	        gnome_setenv ("USER", GdmUser, TRUE);
+	        gnome_setenv ("USERNAME", GdmUser, TRUE);
         }
         if (pwent != NULL) {
 		if (ve_string_empty (pwent->pw_dir))
-			ve_setenv ("HOME", "/", TRUE);
+			gnome_setenv ("HOME", "/", TRUE);
 		else
-			ve_setenv ("HOME", pwent->pw_dir, TRUE);
-	        ve_setenv ("SHELL", pwent->pw_shell, TRUE);
+			gnome_setenv ("HOME", pwent->pw_dir, TRUE);
+	        gnome_setenv ("SHELL", pwent->pw_shell, TRUE);
         } else {
-	        ve_setenv ("HOME", "/", TRUE);
-	        ve_setenv ("SHELL", "/bin/sh", TRUE);
+	        gnome_setenv ("HOME", "/", TRUE);
+	        gnome_setenv ("SHELL", "/bin/sh", TRUE);
         }
 
 	/* Runs as root, uses server authfile */
-	ve_setenv ("XAUTHORITY", d->authfile, TRUE);
-        ve_setenv ("DISPLAY", d->name, TRUE);
-	ve_setenv ("PATH", GdmRootPath, TRUE);
-	ve_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
-	ve_unsetenv ("MAIL");
+	gnome_setenv ("XAUTHORITY", d->authfile, TRUE);
+        gnome_setenv ("DISPLAY", d->name, TRUE);
+	gnome_setenv ("PATH", GdmRootPath, TRUE);
+	gnome_setenv ("RUNNING_UNDER_GDM", "true", TRUE);
+	gnome_unsetenv ("MAIL");
 	argv = ve_split (scr);
 	execv (argv[0], argv);
 	syslog (LOG_ERR, _("gdm_slave_exec_script: Failed starting: %s"), scr);
@@ -2922,10 +2936,10 @@ gdm_parse_enriched_login (const gchar *s, GdmDisplay *display)
 	      dup2 (pipe1[1], STDOUT_FILENO);
 
 	    /* runs as root */
-	    ve_setenv ("XAUTHORITY", display->authfile, TRUE);
-	    ve_setenv ("DISPLAY", display->name, TRUE);
-	    ve_setenv ("PATH", GdmRootPath, TRUE);
-	    ve_unsetenv ("MAIL");
+	    gnome_setenv ("XAUTHORITY", display->authfile, TRUE);
+	    gnome_setenv ("DISPLAY", display->name, TRUE);
+	    gnome_setenv ("PATH", GdmRootPath, TRUE);
+	    gnome_unsetenv ("MAIL");
 
 	    argv = ve_split (str->str);
 	    execv (argv[0], argv);
